The ``true_stress_strain`` module
=================================

Simple conversion functions from technical stress/strain to true
stress/strain including fracture stress/strain.

.. automodule:: pylife.materiallaws.true_stress_strain
	:undoc-members:
	:members:
